.. ref_audiofx:

************
audio.fx
************
This module regroups functions meant to be used with ``audio.fx`` or ``videoclip.fx``. When you type ``from moviepy import *``, the module ``audio.fx`` is loaded as ``afx`` and you can use ``afx.volumex`` etc.


.. automodule:: moviepy.audio.fx
   :members:
   :show-inheritance:
